@@ -31,7 +31,7 @@ readonly ICON_CONFIRM="◎"
 readonly ICON_ADMIN="⚙"
 readonly ICON_SUCCESS="✓"
 readonly ICON_ERROR="☻"
-readonly ICON_WARNING="●"
+readonly ICON_WARNING="◎"
 readonly ICON_EMPTY="○"
 readonly ICON_SOLID="●"
 readonly ICON_LIST="•"
