@@ -175,39 +175,69 @@ batch_uninstall_applications() {
         return 0
     fi
 
+    local old_trap_int old_trap_term
+    old_trap_int=$(trap -p INT)
+    old_trap_term=$(trap -p TERM)
+
+    _restore_uninstall_traps() {
+        if [[ -n "$old_trap_int" ]]; then
+            eval "$old_trap_int"
+        else
+            trap - INT
+        fi
+        if [[ -n "$old_trap_term" ]]; then
+            eval "$old_trap_term"
+        else
+            trap - TERM
+        fi
+    }
+
+    # Trap to clean up spinner and uninstall mode on interrupt
+    trap 'stop_inline_spinner 2>/dev/null; unset MOLE_UNINSTALL_MODE; echo ""; _restore_uninstall_traps; return 130' INT TERM
+
     # Pre-scan: running apps, sudo needs, size.
     local -a running_apps=()
     local -a sudo_apps=()
     local total_estimated_size=0
     local -a app_details=()
 
+    # Cache current user outside loop
+    local current_user=$(whoami)
+
     if [[ -t 1 ]]; then start_inline_spinner "Scanning files..."; fi
     for selected_app in "${selected_apps[@]}"; do
         [[ -z "$selected_app" ]] && continue
         IFS='|' read -r _ app_path app_name bundle_id _ _ <<< "$selected_app"
 
-        # Check running app by bundle executable if available.
+        # Check running app by bundle executable if available
         local exec_name=""
-        if [[ -e "$app_path/Contents/Info.plist" ]]; then
-            exec_name=$(defaults read "$app_path/Contents/Info.plist" CFBundleExecutable 2> /dev/null || echo "")
+        local info_plist="$app_path/Contents/Info.plist"
+        if [[ -e "$info_plist" ]]; then
+            exec_name=$(defaults read "$info_plist" CFBundleExecutable 2> /dev/null || echo "")
         fi
-        local check_pattern="${exec_name:-$app_name}"
-        if pgrep -x "$check_pattern" > /dev/null 2>&1; then
+        if pgrep -qx "${exec_name:-$app_name}" 2> /dev/null; then
             running_apps+=("$app_name")
         fi
 
-        # Check if it's a Homebrew cask (deterministic: resolved path in Caskroom)
-        local cask_name=""
-        cask_name=$(get_brew_cask_name "$app_path" || echo "")
-        local is_brew_cask="false"
-        [[ -n "$cask_name" ]] && is_brew_cask="true"
+        local cask_name="" is_brew_cask="false"
+        local resolved_path=$(readlink "$app_path" 2> /dev/null || echo "")
+        if [[ "$resolved_path" == */Caskroom/* ]]; then
+            # Extract cask name using bash parameter expansion (faster than sed)
+            local tmp="${resolved_path#*/Caskroom/}"
+            cask_name="${tmp%%/*}"
+            [[ -n "$cask_name" ]] && is_brew_cask="true"
+        elif command -v get_brew_cask_name > /dev/null 2>&1; then
+            local detected_cask
+            detected_cask=$(get_brew_cask_name "$app_path" 2> /dev/null || true)
+            if [[ -n "$detected_cask" ]]; then
+                cask_name="$detected_cask"
+                is_brew_cask="true"
+            fi
+        fi
 
-        # Full file scanning for ALL apps (including Homebrew casks)
-        # brew uninstall --cask does NOT remove user data (caches, prefs, app support)
-        # Mole's value is cleaning those up, so we must scan for them
+        # Check if sudo is needed
         local needs_sudo=false
         local app_owner=$(get_file_owner "$app_path")
-        local current_user=$(whoami)
         if [[ ! -w "$(dirname "$app_path")" ]] ||
             [[ "$app_owner" == "root" ]] ||
             [[ -n "$app_owner" && "$app_owner" != "$current_user" ]]; then
@@ -267,7 +297,7 @@ batch_uninstall_applications() {
     done
 
     if [[ "$has_user_data" == "true" ]]; then
-        echo -e "${YELLOW}${ICON_WARNING}${NC} ${YELLOW}Note: Some apps contain user configurations/themes${NC}"
+        echo -e "${GRAY}${ICON_WARNING}${NC} ${YELLOW}Note: Some apps contain user configurations/themes${NC}"
         echo ""
     fi
 
@@ -302,7 +332,7 @@ batch_uninstall_applications() {
         while IFS= read -r file; do
             if [[ -n "$file" && -e "$file" ]]; then
                 if [[ $sys_file_count -lt $max_files ]]; then
-                    echo -e "  ${BLUE}${ICON_SOLID}${NC} System: $file"
+                    echo -e "  ${BLUE}${ICON_WARNING}${NC} System: $file"
                 fi
                 ((sys_file_count++))
             fi
@@ -335,6 +365,7 @@ batch_uninstall_applications() {
         $'\e' | q | Q)
             echo ""
             echo ""
+            _restore_uninstall_traps
             return 0
             ;;
         "" | $'\n' | $'\r' | y | Y)
@@ -343,16 +374,22 @@ batch_uninstall_applications() {
         *)
             echo ""
             echo ""
+            _restore_uninstall_traps
             return 0
             ;;
     esac
 
+    # Enable uninstall mode - allows deletion of data-protected apps (VPNs, dev tools, etc.)
+    # that user explicitly chose to uninstall. System-critical components remain protected.
+    export MOLE_UNINSTALL_MODE=1
+
     # Request sudo if needed.
     if [[ ${#sudo_apps[@]} -gt 0 ]]; then
         if ! sudo -n true 2> /dev/null; then
             if ! request_sudo_access "Admin required for system apps: ${sudo_apps[*]}"; then
                 echo ""
                 log_error "Admin access denied"
+                _restore_uninstall_traps
                 return 1
             fi
         fi
@@ -406,11 +443,12 @@ batch_uninstall_applications() {
         fi
 
         # Remove the application only if not running.
+        # Stop spinner before any removal attempt (avoids mixed output on errors)
+        [[ -t 1 ]] && stop_inline_spinner
+
         local used_brew_successfully=false
         if [[ -z "$reason" ]]; then
             if [[ "$is_brew_cask" == "true" && -n "$cask_name" ]]; then
-                # Stop spinner before brew output
-                [[ -t 1 ]] && stop_inline_spinner
                 # Use brew_uninstall_cask helper (handles env vars, timeout, verification)
                 if brew_uninstall_cask "$cask_name" "$app_path"; then
                     used_brew_successfully=true
@@ -425,7 +463,6 @@ batch_uninstall_applications() {
             elif [[ "$needs_sudo" == true ]]; then
                 if ! safe_sudo_remove "$app_path"; then
                     local app_owner=$(get_file_owner "$app_path")
-                    local current_user=$(whoami)
                     if [[ -n "$app_owner" && "$app_owner" != "$current_user" && "$app_owner" != "root" ]]; then
                         reason="owned by $app_owner"
                     else
@@ -460,13 +497,12 @@ batch_uninstall_applications() {
                 fi
             fi
 
-            # Stop spinner and show success
+            # Show success
             if [[ -t 1 ]]; then
-                stop_inline_spinner
                 if [[ ${#app_details[@]} -gt 1 ]]; then
-                    echo -e "\r\033[K${GREEN}✓${NC} [$current_index/${#app_details[@]}] ${app_name}"
+                    echo -e "${GREEN}✓${NC} [$current_index/${#app_details[@]}] ${app_name}"
                 else
-                    echo -e "\r\033[K${GREEN}✓${NC} ${app_name}"
+                    echo -e "${GREEN}✓${NC} ${app_name}"
                 fi
             fi
 
@@ -477,13 +513,12 @@ batch_uninstall_applications() {
             ((total_items++))
             success_items+=("$app_name")
         else
-            # Stop spinner and show failure
+            # Show failure
             if [[ -t 1 ]]; then
-                stop_inline_spinner
                 if [[ ${#app_details[@]} -gt 1 ]]; then
-                    echo -e "\r\033[K${RED}✗${NC} [$current_index/${#app_details[@]}] ${app_name} ${GRAY}($reason)${NC}"
+                    echo -e "${ICON_ERROR} [$current_index/${#app_details[@]}] ${app_name} ${GRAY}($reason)${NC}"
                 else
-                    echo -e "\r\033[K${RED}✗${NC} ${app_name} failed: $reason"
+                    echo -e "${ICON_ERROR} ${app_name} failed: $reason"
                 fi
             fi
 
@@ -624,12 +659,18 @@ batch_uninstall_applications() {
         sudo_keepalive_pid=""
     fi
 
+    # Disable uninstall mode
+    unset MOLE_UNINSTALL_MODE
+
     # Invalidate cache if any apps were successfully uninstalled.
     if [[ $success_count -gt 0 ]]; then
         local cache_file="$HOME/.cache/mole/app_scan_cache"
         rm -f "$cache_file" 2> /dev/null || true
     fi
 
+    _restore_uninstall_traps
+    unset -f _restore_uninstall_traps
+
     ((total_size_cleaned += total_size_freed))
     unset failed_items
 }
